@@ -16,9 +16,15 @@ def run():
     copytree(my_repo, 'my_repo', symlinks=True)
 
     # 2. prepare repositories you'd be using. For this demo we only set up Hypothesis
-    hypothesis_repo = abspath('hypothesis_repo')
-    check_call(['git', 'clone', 'https://github.com/karlicoss/hypexport.git', hypothesis_repo])
-    #
+    tox = 'TOX' in os.environ
+    if tox: # tox doesn't like --user flag
+        check_call('pip3 install        git+https://github.com/karlicoss/hypexport.git'.split())
+    else:
+        try:
+            import hypexport
+        except ModuleNotFoundError:
+            check_call('pip3 install --user git+https://github.com/karlicoss/hypexport.git'.split())
+
 
     # 3. prepare some demo Hypothesis data
     hypothesis_backups = abspath('backups/hypothesis')
@@ -31,8 +37,8 @@ def run():
     #
 
     # 4. point my.config to the Hypothesis data
-    mycfg_root = abspath('my_repo/doc/example_config')
-    init_file = Path(mycfg_root) / 'my/config/__init__.py'
+    mycfg_root = abspath('my_repo')
+    init_file = Path(mycfg_root) / 'my/config.py'
     init_file.write_text(init_file.read_text().replace(
         '/path/to/hypothesis/data',
         hypothesis_backups,
@@ -45,7 +51,7 @@ def run():
     check_call(['python3', '-c', '''
 import my.hypothesis
 
-pages = my.hypothesis.get_pages()
+pages = my.hypothesis.pages()
 
 from itertools import islice
 for page in islice(pages, 0, 8):
