@@ -95,3 +95,43 @@ class commits:
 
 class pdfs:
     paths: Paths
+
+
+class zulip:
+    class organization:
+        export_path: Paths
+
+
+class bumble:
+    class android:
+        export_path: Paths
+
+
+class instagram:
+    class android:
+        export_path: Paths
+    class gdpr:
+        export_path: Paths
+
+
+class hackernews:
+    class dogsheep:
+        export_path: Paths
+
+
+class fbmessenger:
+    class fbmessengerexport:
+        export_db: PathIsh
+    class android:
+        export_path: Paths
+
+
+class twitter:
+    class talon:
+        export_path: Paths
+
+class browser:
+    class export:
+        export_path: Paths = ''
+    class active_browser:
+        export_path: Paths = ''
