@@ -105,7 +105,7 @@ def config_create() -> None:
 # hpi config check
 
 # to quickly check a specific module setup, run hpi doctor <module>, e.g.:
-# hpi doctor my.reddit
+# hpi doctor my.reddit.rexport
 
 ### useful default imports
 from my.core import Paths, PathIsh, get_files
@@ -222,6 +222,7 @@ def modules_check(*, verbose: bool, list_all: bool, quick: bool, for_modules: Li
 
     from .util import get_stats, HPIModule
     from .stats import guess_stats
+    from .error import warn_my_config_import_error
 
     mods: Iterable[HPIModule]
     if len(for_modules) == 0:
@@ -242,6 +243,10 @@ def modules_check(*, verbose: bool, list_all: bool, quick: bool, for_modules: Li
         except Exception as e:
             # todo more specific command?
             error(f'{click.style("FAIL", fg="red")}: {m:<50} loading failed{vw}')
+            # check that this is an import error in particular, not because
+            # of a ModuleNotFoundError because some dependency wasnt installed
+            if isinstance(e, (ImportError, AttributeError)):
+                warn_my_config_import_error(e)
             if verbose:
                 tb(e)
             continue
@@ -393,7 +398,7 @@ def _locate_functions_or_prompt(qualified_names: List[str], prompt: bool = True)
                     if prompt is False:
                         # theres more than one possible data provider in this module,
                         # STDOUT is not a TTY, can't prompt
-                        eprint(f"During fallback, more than one possible data provider, can't prompt since STDOUT is not a TTY")
+                        eprint("During fallback, more than one possible data provider, can't prompt since STDOUT is not a TTY")
                         eprint("Specify one of:")
                         for funcname in choices:
                             eprint(f"\t{qualname}.{funcname}")
@@ -410,7 +415,7 @@ def _locate_functions_or_prompt(qualified_names: List[str], prompt: bool = True)
 def query_hpi_functions(
     *,
     output: str = 'json',
-    stream_json: bool = False,
+    stream: bool = False,
     qualified_names: List[str],
     order_key: Optional[str],
     order_by_value_type: Optional[Type],
@@ -447,7 +452,7 @@ def query_hpi_functions(
     if output == 'json':
         from .serialize import dumps
 
-        if stream_json:
+        if stream:
             for item in res:
                 # use sys.stdout directly
                 # the overhead form click.echo isn't a *lot*, but when called in a loop
@@ -460,7 +465,11 @@ def query_hpi_functions(
     elif output == 'pprint':
         from pprint import pprint
 
-        pprint(list(res))
+        if stream:
+            for item in res:
+                pprint(item)
+        else:
+            pprint(list(res))
     else:
         res = list(res)  # type: ignore[assignment]
         # output == 'repl'
@@ -476,13 +485,18 @@ def query_hpi_functions(
 
 
 @click.group()
-def main() -> None:
+@click.option("--debug", is_flag=True, default=False, help="Show debug logs")
+def main(debug: bool) -> None:
     '''
     Human Programming Interface
 
     Tool for HPI
     Work in progress, will be used for config management, troubleshooting & introspection
     '''
+    # should overwrite anything else in HPI_LOGS
+    if debug:
+        os.environ["HPI_LOGS"] = "debug"
+
     # for potential future reference, if shared state needs to be added to groups
     # https://click.palletsprojects.com/en/7.x/commands/#group-invocation-without-command
     # https://click.palletsprojects.com/en/7.x/commands/#multi-command-chaining
@@ -505,17 +519,28 @@ def main() -> None:
     os.chdir(tdir)
 
 
+@functools.lru_cache(maxsize=1)
+def _all_mod_names() -> List[str]:
+    """Should include all modules, in case user is trying to diagnose issues"""
+    # sort this, so that the order doesn't change while tabbing through
+    return sorted([m.name for m in modules()])
+
+
+def _module_autocomplete(ctx: click.Context, args: Sequence[str], incomplete: str) -> List[str]:
+    return [m for m in _all_mod_names() if m.startswith(incomplete)]
+
+
 @main.command(name='doctor', short_help='run various checks')
 @click.option('--verbose/--quiet', default=False, help='Print more diagnostic information')
 @click.option('--all', 'list_all', is_flag=True, help='List all modules, including disabled')
-@click.option('--quick', is_flag=True, help='Only run partial checks (first 100 items)')
-@click.option('--skip-config-check', 'skip_conf', is_flag=True, help='Skip configuration check')
-@click.argument('MODULE', nargs=-1, required=False)
+@click.option('-q', '--quick', is_flag=True, help='Only run partial checks (first 100 items)')
+@click.option('-S', '--skip-config-check', 'skip_conf', is_flag=True, help='Skip configuration check')
+@click.argument('MODULE', nargs=-1, required=False, shell_complete=_module_autocomplete)
 def doctor_cmd(verbose: bool, list_all: bool, quick: bool, skip_conf: bool, module: Sequence[str]) -> None:
     '''
     Run various checks
 
-    MODULE is one or more specific module names to check (e.g. my.reddit)
+    MODULE is one or more specific module names to check (e.g. my.reddit.rexport)
     Otherwise, checks all modules
     '''
     if not skip_conf:
@@ -557,24 +582,24 @@ def module_grp() -> None:
 
 
 @module_grp.command(name='requires', short_help='print module reqs')
-@click.argument('MODULE')
+@click.argument('MODULE', shell_complete=_module_autocomplete)
 def module_requires_cmd(module: str) -> None:
     '''
     Print MODULE requirements
 
-    MODULE is a specific module name (e.g. my.reddit)
+    MODULE is a specific module name (e.g. my.reddit.rexport)
     '''
     module_requires(module=module)
 
 
 @module_grp.command(name='install', short_help='install module deps')
 @click.option('--user', is_flag=True, help='same as pip --user')
-@click.argument('MODULE')
+@click.argument('MODULE', shell_complete=_module_autocomplete)
 def module_install_cmd(user: bool, module: str) -> None:
     '''
     Install dependencies for a module using pip
 
-    MODULE is a specific module name (e.g. my.reddit)
+    MODULE is a specific module name (e.g. my.reddit.rexport)
     '''
     # todo could add functions to check specific module etc..
     module_install(user=user, module=module)
@@ -590,7 +615,7 @@ def module_install_cmd(user: bool, module: str) -> None:
               '--stream',
               default=False,
               is_flag=True,
-              help='stream json objects from the data source instead of printing a list at the end')
+              help='stream objects from the data source instead of printing a list at the end')
 @click.option('-k',
               '--order-key',
               default=None,
@@ -601,26 +626,31 @@ def module_install_cmd(user: bool, module: str) -> None:
               default=None,
               type=click.Choice(['datetime', 'date', 'int', 'float']),
               help='order by searching for some type on the iterable')
-@click.option('--after',
+@click.option('-a',
+              '--after',
               default=None,
               type=str,
               help='while ordering, filter items for the key or type larger than or equal to this')
-@click.option('--before',
+@click.option('-b',
+              '--before',
               default=None,
               type=str,
               help='while ordering, filter items for the key or type smaller than this')
-@click.option('--within',
+@click.option('-w',
+              '--within',
               default=None,
               type=str,
               help="a range 'after' or 'before' to filter items by. see above for further explanation")
-@click.option('--recent',
+@click.option('-r',
+              '--recent',
               default=None,
               type=str,
               help="a shorthand for '--order-type datetime --reverse --before now --within'. e.g. --recent 5d")
 @click.option('--reverse/--no-reverse',
               default=False,
               help='reverse the results returned from the functions')
-@click.option('--limit',
+@click.option('-l',
+              '--limit',
               default=None,
               type=int,
               help='limit the number of items returned from the (functions)')
@@ -640,7 +670,7 @@ def module_install_cmd(user: bool, module: str) -> None:
               default=False,
               is_flag=True,
               help='ignore any errors returned as objects from the functions')
-@click.argument('FUNCTION_NAME', nargs=-1, required=True)
+@click.argument('FUNCTION_NAME', nargs=-1, required=True, shell_complete=_module_autocomplete)
 def query_cmd(
     function_name: Sequence[str],
     output: str,
@@ -676,13 +706,13 @@ def query_cmd(
     As an example, to query reddit comments I've made in the last month
 
     \b
-    hpi query --order-type datetime --before now --within 4w my.reddit.comments
+    hpi query --order-type datetime --before now --within 4w my.reddit.all.comments
     or...
-    hpi query --recent 4w my.reddit.comments
+    hpi query --recent 4w my.reddit.all.comments
 
     \b
     Can also query within a range. To filter comments between 2016 and 2018:
-    hpi query --order-type datetime --after '2016-01-01 00:00:00' --before '2019-01-01 00:00:00' my.reddit.comments
+    hpi query --order-type datetime --after '2016-01-01 00:00:00' --before '2019-01-01 00:00:00' my.reddit.all.comments
     '''
 
     from datetime import datetime, date
@@ -710,7 +740,7 @@ def query_cmd(
     try:
         query_hpi_functions(
             output=output,
-            stream_json=stream,
+            stream=stream,
             qualified_names=list(function_name),
             order_key=order_key,
             order_by_value_type=chosen_order_type,
