@@ -163,12 +163,6 @@ from .logging import setup_logger, LazyLogger
 Paths = Union[Sequence[PathIsh], PathIsh]
 
 
-def _is_compressed(p: Path) -> bool:
-    # todo kinda lame way for now.. use mime ideally?
-    # should cooperate with kompress.kopen?
-    return p.suffix in {'.xz', '.lz4', '.zstd'}
-
-
 DEFAULT_GLOB = '*'
 def get_files(
         pp: Paths,
@@ -233,8 +227,8 @@ def get_files(
         traceback.print_stack()
 
     if guess_compression:
-        from .kompress import CPath
-        paths = [CPath(p) if _is_compressed(p) else p for p in paths]
+        from .kompress import CPath, is_compressed
+        paths = [CPath(p) if is_compressed(p) else p for p in paths]
     return tuple(paths)
 
 
@@ -358,12 +352,11 @@ def isoparse(s: str) -> tzdatetime:
     """
     Parses timestamps formatted like 2020-05-01T10:32:02.925961Z
     """
-    from .compat import fromisoformat
     # TODO could use dateutil? but it's quite slow as far as I remember..
     # TODO support non-utc.. somehow?
     assert s.endswith('Z'), s
     s = s[:-1] + '+00:00'
-    return fromisoformat(s)
+    return datetime.fromisoformat(s)
 
 from .compat import Literal
 
@@ -572,7 +565,7 @@ def test_guess_datetime() -> None:
 def is_namedtuple(thing: Any) -> bool:
     # basic check to see if this is namedtuple-like
     _asdict = getattr(thing, '_asdict', None)
-    return _asdict and callable(_asdict)
+    return (_asdict is not None) and callable(_asdict)
 
 
 def asdict(thing: Any) -> Json:
@@ -607,7 +600,10 @@ class DummyExecutor(Executor):
         self._shutdown = False
         self._max_workers = max_workers
 
-    def submit(self, fn, *args, **kwargs) -> Future:
+    # TODO: once support for 3.7 is dropped,
+    # can make 'fn' a positional only parameter,
+    # which fixes the mypy error this throws without the type: ignore
+    def submit(self, fn, *args, **kwargs) -> Future:  # type: ignore[override]
         if self._shutdown:
             raise RuntimeError('cannot schedule new futures after shutdown')
 
@@ -623,5 +619,5 @@ class DummyExecutor(Executor):
 
         return f
 
-    def shutdown(self, wait: bool=True) -> None:
+    def shutdown(self, wait: bool=True) -> None:  # type: ignore[override]
         self._shutdown = True
