@@ -4,7 +4,7 @@ See https://beepb00p.xyz/mypy-error-handling.html#kiss for more detail
 """
 
 from itertools import tee
-from typing import Union, TypeVar, Iterable, List, Tuple, Type, Optional, Callable, Any
+from typing import Union, TypeVar, Iterable, List, Tuple, Type, Optional, Callable, Any, cast
 
 
 T = TypeVar('T')
@@ -127,8 +127,8 @@ def attach_dt(e: Exception, *, dt: Optional[datetime]) -> Exception:
 
 # todo it might be problematic because might mess with timezones (when it's converted to string, it's converted to a shift)
 def extract_error_datetime(e: Exception) -> Optional[datetime]:
-    from .compat import fromisoformat
     import re
+    from datetime import datetime
     for x in reversed(e.args):
         if isinstance(x, datetime):
             return x
@@ -139,7 +139,7 @@ def extract_error_datetime(e: Exception) -> Optional[datetime]:
             continue
         ss = m.group(0)
         # todo not sure if should be defensive??
-        return fromisoformat(ss)
+        return datetime.fromisoformat(ss)
     return None
 
 
@@ -150,6 +150,47 @@ def error_to_json(e: Exception) -> Json:
     return {'error': estr}
 
 
+MODULE_SETUP_URL = 'https://github.com/karlicoss/HPI/blob/master/doc/SETUP.org#private-configuration-myconfig'
+
+def warn_my_config_import_error(err: Union[ImportError, AttributeError], help_url: str = MODULE_SETUP_URL) -> bool:
+    """
+    If the user tried to import something from my.config but it failed,
+    possibly due to missing the config block in my.config?
+
+    Returns True if it matched a possible config error
+    """
+    import re
+    import click
+    if type(err) == ImportError:
+        if err.name != 'my.config':
+            return False
+        # parse name that user attempted to import
+        em = re.match(r"cannot import name '(\w+)' from 'my.config'", str(err))
+        if em is not None:
+            section_name = em.group(1)
+            click.secho(f"""\
+You may be missing the '{section_name}' section from your config.
+See {help_url}\
+""", fg='yellow', err=True)
+            return True
+    elif type(err) == AttributeError:
+        # test if user had a nested config block missing
+        # https://github.com/karlicoss/HPI/issues/223
+        if hasattr(err, 'obj') and hasattr(err, "name"):
+            config_obj = cast(object, getattr(err, 'obj'))  # the object that caused the attribute error
+            # e.g. active_browser for my.browser
+            nested_block_name = err.name  # type: ignore[attr-defined]
+            if config_obj.__module__ == 'my.config':
+                click.secho(f"""You're likely missing the nested config block for '{getattr(config_obj, '__name__', str(config_obj))}.{nested_block_name}'.
+See {help_url} or check the corresponding module.py file for an example\
+""", fg='yellow', err=True)
+                return True
+    else:
+        click.echo(f"Unexpected error... {err}", err=True)
+    return False
+
+
+
 def test_datetime_errors() -> None:
     import pytz
     dt_notz = datetime.now()
