@@ -16,3 +16,10 @@ from my.core.core_config    import *
 from my.core.error          import *
 from my.core.util           import *
 from my.core.discovery_pure import *
+from my.core.freezer        import *
+from my.core.stats          import *
+from my.core.query          import *
+from my.core.query_range    import *
+from my.core.serialize      import test_serialize_fallback
+from my.core.sqlite         import *
+from my.core.__main__       import *
